@@ -1,10 +1,14 @@
 # pylint: disable-msg= W0611
 from .merge import merge
 from .mass_update import mass_update
-from .export import export_as_fixture, export_as_csv, export_delete_tree
+from .export import export_as_fixture, export_as_csv, export_delete_tree, export_as_xls
 from .graph import graph_queryset
 
-actions = [export_as_fixture, export_as_csv, export_delete_tree, merge, mass_update,
+actions = [export_as_fixture,
+           export_as_csv,
+           export_as_xls,
+           export_delete_tree,
+           merge, mass_update,
            graph_queryset]
 
 
